summaryrefslogtreecommitdiff
path: root/sw/source/core/txtnode
diff options
context:
space:
mode:
authorMiklos Vajna <vmiklos@collabora.co.uk>2013-10-26 19:50:13 +0200
committerMiklos Vajna <vmiklos@collabora.co.uk>2013-10-26 20:03:50 +0200
commitee3189489c0205ec221fbc907a01c711b58fc42e (patch)
tree1cd2fd05e3518d9484b11f0fc29b6e458a629338 /sw/source/core/txtnode
parent2e99447fc07df98ebbc343ef79852b7eaf7b7757 (diff)
sw: ViewShell -> SwViewShell rename
It's a public class, so it should have the 'Sw' prefix. Change-Id: I0040c1cc37ffcba7fc5f58b71c86f4a7cb0bfce4
Diffstat (limited to 'sw/source/core/txtnode')
-rw-r--r--sw/source/core/txtnode/fntcache.cxx18
-rw-r--r--sw/source/core/txtnode/fntcap.cxx2
-rw-r--r--sw/source/core/txtnode/swfntcch.cxx4
-rw-r--r--sw/source/core/txtnode/swfont.cxx12
4 files changed, 18 insertions, 18 deletions
diff --git a/sw/source/core/txtnode/fntcap.cxx b/sw/source/core/txtnode/fntcap.cxx
index 892273778f01..a73cf97d8049 100644
--- a/sw/source/core/txtnode/fntcap.cxx
+++ b/sw/source/core/txtnode/fntcap.cxx
@@ -243,7 +243,7 @@ void SwDoGetCapitalBreak::Do()
* SwFont::GetCapitalBreak()
*************************************************************************/
-xub_StrLen SwFont::GetCapitalBreak( ViewShell* pSh, const OutputDevice* pOut,
+xub_StrLen SwFont::GetCapitalBreak( SwViewShell* pSh, const OutputDevice* pOut,
const SwScriptInfo* pScript, const OUString& rTxt, long const nTextWidth,
const xub_StrLen nIdx, const xub_StrLen nLen )
{
diff --git a/sw/source/core/txtnode/swfntcch.cxx b/sw/source/core/txtnode/swfntcch.cxx
index fbf867b5378b..803891177e03 100644
--- a/sw/source/core/txtnode/swfntcch.cxx
+++ b/sw/source/core/txtnode/swfntcch.cxx
@@ -35,7 +35,7 @@ SwFontCache *pSwFontCache = NULL;
|*
|*************************************************************************/
-SwFontObj::SwFontObj( const void *pOwn, ViewShell *pSh ) :
+SwFontObj::SwFontObj( const void *pOwn, SwViewShell *pSh ) :
SwCacheObj( (void*)pOwn ),
aSwFont( &((SwTxtFmtColl *)pOwn)->GetAttrSet(), pSh ? pSh->getIDocumentSettingAccess() : 0 )
{
@@ -55,7 +55,7 @@ SwFontObj::~SwFontObj()
|*
|*************************************************************************/
-SwFontAccess::SwFontAccess( const void *pOwn, ViewShell *pSh ) :
+SwFontAccess::SwFontAccess( const void *pOwn, SwViewShell *pSh ) :
SwCacheAccess( *pSwFontCache, pOwn,
((SwTxtFmtColl*)pOwn)->IsInSwFntCache() ),
pShell( pSh )
diff --git a/sw/source/core/txtnode/swfont.cxx b/sw/source/core/txtnode/swfont.cxx
index 0a361cac51a7..11b559a52a55 100644
--- a/sw/source/core/txtnode/swfont.cxx
+++ b/sw/source/core/txtnode/swfont.cxx
@@ -960,19 +960,19 @@ SwFont& SwFont::operator=( const SwFont &rFont )
return *this;
}
-void SwFont::GoMagic( ViewShell *pSh, sal_uInt8 nWhich )
+void SwFont::GoMagic( SwViewShell *pSh, sal_uInt8 nWhich )
{
SwFntAccess aFntAccess( aSub[nWhich].pMagic, aSub[nWhich].nFntIndex,
&aSub[nWhich], pSh, sal_True );
}
-sal_Bool SwSubFont::IsSymbol( ViewShell *pSh )
+sal_Bool SwSubFont::IsSymbol( SwViewShell *pSh )
{
SwFntAccess aFntAccess( pMagic, nFntIndex, this, pSh, sal_False );
return aFntAccess.Get()->IsSymbol();
}
-sal_Bool SwSubFont::ChgFnt( ViewShell *pSh, OutputDevice& rOut )
+sal_Bool SwSubFont::ChgFnt( SwViewShell *pSh, OutputDevice& rOut )
{
if ( pLastFont )
pLastFont->Unlock();
@@ -989,7 +989,7 @@ sal_Bool SwSubFont::ChgFnt( ViewShell *pSh, OutputDevice& rOut )
STRIKEOUT_NONE != GetStrikeout();
}
-void SwFont::ChgPhysFnt( ViewShell *pSh, OutputDevice& rOut )
+void SwFont::ChgPhysFnt( SwViewShell *pSh, OutputDevice& rOut )
{
if( bOrgChg && aSub[nActual].IsEsc() )
{
@@ -1046,7 +1046,7 @@ short SwSubFont::_CheckKerning( )
return nKernx;
}
-sal_uInt16 SwSubFont::GetAscent( ViewShell *pSh, const OutputDevice& rOut )
+sal_uInt16 SwSubFont::GetAscent( SwViewShell *pSh, const OutputDevice& rOut )
{
sal_uInt16 nAscent;
SwFntAccess aFntAccess( pMagic, nFntIndex, this, pSh );
@@ -1056,7 +1056,7 @@ sal_uInt16 SwSubFont::GetAscent( ViewShell *pSh, const OutputDevice& rOut )
return nAscent;
}
-sal_uInt16 SwSubFont::GetHeight( ViewShell *pSh, const OutputDevice& rOut )
+sal_uInt16 SwSubFont::GetHeight( SwViewShell *pSh, const OutputDevice& rOut )
{
SV_STAT( nGetTextSize );
SwFntAccess aFntAccess( pMagic, nFntIndex, this, pSh );
diff --git a/sw/source/core/txtnode/fntcache.cxx b/sw/source/core/txtnode/fntcache.cxx
index 59660bc1cd90..aa7349b50318 100644
--- a/sw/source/core/txtnode/fntcache.cxx
+++ b/sw/source/core/txtnode/fntcache.cxx
@@ -103,7 +103,7 @@ void SwFntCache::Flush( )
|*
|*************************************************************************/
-SwFntObj::SwFntObj( const SwSubFont &rFont, const void *pOwn, ViewShell *pSh ) :
+SwFntObj::SwFntObj( const SwSubFont &rFont, const void *pOwn, SwViewShell *pSh ) :
SwCacheObj( (void*)pOwn ),
aFont( rFont ),
pScrFont( NULL ),
@@ -279,7 +279,7 @@ static void lcl_calcLinePos( const CalcLinePosData &rData,
* it may be necessary to create the screen font first.
*************************************************************************/
-sal_uInt16 SwFntObj::GetFontAscent( const ViewShell *pSh, const OutputDevice& rOut )
+sal_uInt16 SwFntObj::GetFontAscent( const SwViewShell *pSh, const OutputDevice& rOut )
{
sal_uInt16 nRet = 0;
const OutputDevice& rRefDev = pSh ? pSh->GetRefDev() : rOut;
@@ -322,7 +322,7 @@ sal_uInt16 SwFntObj::GetFontAscent( const ViewShell *pSh, const OutputDevice& rO
* it may be necessary to create the screen font first.
*************************************************************************/
-sal_uInt16 SwFntObj::GetFontHeight( const ViewShell* pSh, const OutputDevice& rOut )
+sal_uInt16 SwFntObj::GetFontHeight( const SwViewShell* pSh, const OutputDevice& rOut )
{
sal_uInt16 nRet = 0;
const OutputDevice& rRefDev = pSh ? pSh->GetRefDev() : rOut;
@@ -362,7 +362,7 @@ sal_uInt16 SwFntObj::GetFontHeight( const ViewShell* pSh, const OutputDevice& rO
return nRet;
}
-sal_uInt16 SwFntObj::GetFontLeading( const ViewShell *pSh, const OutputDevice& rOut )
+sal_uInt16 SwFntObj::GetFontLeading( const SwViewShell *pSh, const OutputDevice& rOut )
{
sal_uInt16 nRet = 0;
@@ -416,13 +416,13 @@ sal_uInt16 SwFntObj::GetFontLeading( const ViewShell *pSh, const OutputDevice& r
/*************************************************************************
*
* SwFntObj::CreateScrFont( const ViewShell& rSh, const OutputDevice& rOut )
*
* pOut is the output device, not the reference device
*
*************************************************************************/
-void SwFntObj::CreateScrFont( const ViewShell& rSh, const OutputDevice& rOut )
+void SwFntObj::CreateScrFont( const SwViewShell& rSh, const OutputDevice& rOut )
{
if ( pScrFont )
return;
@@ -516,7 +516,7 @@ void SwFntObj::CreateScrFont( const ViewShell& rSh, const OutputDevice& rOut )
}
-void SwFntObj::GuessLeading( const ViewShell&
+void SwFntObj::GuessLeading( const SwViewShell&
#if defined(WNT)
rSh
#endif
@@ -601,7 +601,7 @@ void SwFntObj::GuessLeading( const ViewShell&
*
*************************************************************************/
-void SwFntObj::SetDevFont( const ViewShell *pSh, OutputDevice& rOut )
+void SwFntObj::SetDevFont( const SwViewShell *pSh, OutputDevice& rOut )
{
const OutputDevice& rRefDev = pSh ? pSh->GetRefDev() : rOut;
@@ -2228,7 +2228,7 @@ xub_StrLen SwFntObj::GetCrsrOfst( SwDrawTextInfo &rInf )
|*************************************************************************/
SwFntAccess::SwFntAccess( const void* &rMagic,
- sal_uInt16 &rIndex, const void *pOwn, ViewShell *pSh,
+ sal_uInt16 &rIndex, const void *pOwn, SwViewShell *pSh,
sal_Bool bCheck ) :
SwCacheAccess( *pFntCache, rMagic, rIndex ),
pShell( pSh )
@@ -416,13 +416,13 @@ sal_uInt16 SwFntObj::GetFontLeading( const ViewShell *pSh, const OutputDevice& r
/*************************************************************************
*
- * SwFntObj::CreateScrFont( const ViewShell& rSh, const OutputDevice& rOut )
+ * SwFntObj::CreateScrFont( const SwViewShell& rSh, const OutputDevice& rOut )
*
* pOut is the output device, not the reference device